#!/bin/sh
#
# source: http://ftp.gnome.org/pub/gnome/sources/vte/0.28/vte-0.28.2.tar.xz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft='vte'
softversion='0.28.2'
packageversion='72.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.xz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --disable-static \
  --with-gtk=2.0 \
  --with-html-dir=/usr/doc/$soft-$softversion

make -j6
make install DESTDIR=$dest

# this part of vte (gnome-pty-helper) is in vte3 package now

rm -rf $dest/usr/libexec

find $dest | xargs file | grep -e "executable" -e "shared object" \
  | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

#-------------------Prepare the documentation

cp -a \
  AUTHORS ChangeLog COPYING HACKING MAINTAINERS NEWS README \
  $dest/usr/doc/$soft-$softversion

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

   |-----handy-ruler------------------------------------------------------|
vte: vte -is terminal emulator widget
vte:
vte: VTE is a terminal emulator widget for use with GTK+.  This package
vte: contains the VTE library and development files and a sample
vte: implementation (vte).
vte:
vte:
vte:
vte:
vte:
vte:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5